@@ -9,7 +9,8 @@ from .fixtures import cache_content, scenario_constant_rain_content
 def test_scenario_meta(tmp_path, scenario_constant_rain_content):
     crf = tmp_path / "constant_rain.yaml"
     with open(crf, "w") as f:
-        yaml.dump(scenario_constant_rain_content,
+        yaml.dump(
+            scenario_constant_rain_content,
             default_flow_style=False,
             stream=f,
         )
