@@ -28,9 +28,7 @@ async def monitor_active_simulations(endpoint: str) -> None:
 
 
 @active_sims_app.command()
-def simulations(
-        ctx: typer.Context
-):
+def simulations(ctx: typer.Context):
     """
     Show currently running simulations
     """
@@ -47,5 +45,5 @@ def simulations(
         )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     active_sims_app()
