@@ -12,8 +12,8 @@ import click
 import yaml
 from rich.prompt import Prompt
 
-from openapi_client import Configuration, ApiClient, ApiException
-from threedi_api_client.threedi_api_client import ThreediApiClient
+from threedi_api_client.threedi_api_client import ThreediApiClient, Configuration
+from threedi_api_client.openapi.exceptions import ApiException
 from threedi_api_client.api import ThreediApi
 from threedi_api_client.aio.threedi_api_client import (
     ThreediApiClient as AsyncThreediApiClient,
@@ -61,9 +61,7 @@ class WebSocketSettings:
         self.proto = "wss" if parsed_url.scheme == "https" else "ws"
         self.api_version = parsed_url.path.lstrip("/")
         self.token = (
-            self.token
-            if self.token.startswith("Bearer")
-            else f"Bearer {self.token}"
+            self.token if self.token.startswith("Bearer") else f"Bearer {self.token}"
         )
 
 
@@ -131,16 +129,16 @@ class Settings:
     APP_NAME = "3di-scenario"
     CONFIG_FILE_NAME = "3di_config.yaml"
 
-    def __init__(self, endpoint: str = "", websocket_api_version='v3-beta'):
+    def __init__(self, endpoint: str = "", websocket_api_version="v3-beta"):
         self._endpoint = EndpointOption[endpoint]
         self.cached_config = CachedConfig.load_from_file(self.config_file)
         try:
             refresh_api_key(self.configuration)
         except ValueError:
             self.credentials_prompt(self.configuration)
-        
+
         self.websocket_settings = WebSocketSettings(
-            api_base_url=self.endpoint + '/' + websocket_api_version, token=self.access
+            api_base_url=self.endpoint + "/" + websocket_api_version, token=self.access
         )
 
     @property
@@ -233,9 +231,9 @@ class Settings:
                 "THREEDI_API_HOST": self.endpoint,
                 "THREEDI_API_USERNAME": self.username,
                 "THREEDI_API_ACCESS_TOKEN": self.access,
-                "THREEDI_API_REFRESH_TOKEN": self.refresh
-            }
-            , version='v3-beta'
+                "THREEDI_API_REFRESH_TOKEN": self.refresh,
+            },
+            version="v3-beta",
         )
         return client
 
@@ -254,8 +252,7 @@ class Settings:
             self.cached_config.save_to_file(self.config_file)
         except IOError as err:
             console.print(
-                f"Saving cache to {self.config_file} failed with: {err}",
-                style="error"
+                f"Saving cache to {self.config_file} failed with: {err}", style="error"
             )
             return
 
@@ -286,7 +283,10 @@ class Settings:
             sys.exit(ExitCodes.AUTHENTICATION_FAILED.value)
         except ApiException as err:
             body = json.loads(err.body)["detail"]
-            console.print(f"Could not log you in. The server responded with: {body}", style="error")
+            console.print(
+                f"Could not log you in. The server responded with: {body}",
+                style="error",
+            )
             sys.exit(ExitCodes.AUTHENTICATION_FAILED.value)
 
         # Update the settings
