@@ -149,7 +149,7 @@ class ModelWrapper(BaseWrapper):
         if res is not None:
             # Update values of self to match what has been returned
             for key, value in res.to_dict().items():
-                if hasattr(self.instance, key):
+                if hasattr(self.instance, key) and value is not None:
                     setattr(self.instance, key, value)
 
             self._internal_state = res
