@@ -1,12 +1,10 @@
 import asyncio
 from asyncio import Queue
 from dataclasses import dataclass
-from pathlib import Path
 from time import time
 from typing import Dict
-
-from openapi_client import SimulationsApi, ApiClient, Simulation
-from openapi_client.models import SimulationStatus
+from threedi_api_client.openapi.api.v3_api import V3Api
+from threedi_api_client.openapi.models import SimulationStatus
 from rich.progress import (
     BarColumn,
     TextColumn,
@@ -53,17 +51,11 @@ def match(websocket_instance, data: Dict):
 
 
 class WaitForBase(SimulationChildWrapper):
-    api_class = SimulationsApi
     model = None  # Override this
     scenario_name = ""  # Override this
     websocket_event_type = ""  # Override this
 
-    def __init__(
-        self,
-        data: Dict,
-        api_client: ApiClient,
-        **kwargs
-    ):
+    def __init__(self, data: Dict, api_client: V3Api, **kwargs):
         """Set the timeout to -1 to wait infinitely for the event"""
         if "timeout" in data:
             self.timeout = data.pop("timeout")
@@ -119,16 +111,12 @@ class WaitForBase(SimulationChildWrapper):
             )
             while waiting:
                 try:
-                    data = await asyncio.wait_for(
-                        queue.get(), timeout=remaining_time
-                    )
+                    data = await asyncio.wait_for(queue.get(), timeout=remaining_time)
                     try:
                         sim_time = data["sim_time"]
                     except (KeyError, TypeError):
                         pass
-                    progress.update(
-                        task, remaining=int(remaining_time), t=sim_time
-                    )
+                    progress.update(task, remaining=int(remaining_time), t=sim_time)
                 except asyncio.TimeoutError:
                     raise WaitForTimeout(f"Timeout error for: {description}")
                 instance = self.get_instance(data)
@@ -138,18 +126,13 @@ class WaitForBase(SimulationChildWrapper):
                         progress.update(task, advance=1)
                         waiting = False
 
-                if (
-                    data.get("type") == "websocket"
-                    and data.get("status") == "closing"
-                ):
+                if data.get("type") == "websocket" and data.get("status") == "closing":
                     raise WaitForTimeout(data.get("reason"))
 
                 if waiting and remaining_time is not None:
                     remaining_time = float(self.timeout) - (time() - start)
                     if remaining_time <= 0:
-                        raise WaitForTimeout(
-                            f"Timeout error for: {description}"
-                        )
+                        raise WaitForTimeout(f"Timeout error for: {description}")
         console.print(f":heavy_check_mark: Received {self}!")
         console.print("• Resuming scenario...")
         return instance
@@ -183,7 +166,6 @@ class WaitForModel(WaitForBase):
 
 
 class WaitForStatusWrapper(WaitForModel):
-    api_class = SimulationsApi
     model = SimulationStatus
     scenario_name = "waitforstatus"
     websocket_event_type = "status"
@@ -222,15 +204,10 @@ class Time:
     load: float = None
     simulation_id: str = None
 
-    openapi_types = {
-        "time": "time",
-        "load": "load",
-        "simulation_id": "simulation_id"
-    }
+    openapi_types = {"time": "time", "load": "load", "simulation_id": "simulation_id"}
 
 
 class WaitForTimeWrapper(WaitForBase):
-    api_class = SimulationsApi
     model = Time
     scenario_name = "waitfortime"
     websocket_event_type = "time"
